Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1346)

Unified Diff: content/public/browser/utility_process_host.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/render_process_host.h ('k') | content/public/browser/web_contents.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/utility_process_host.h
diff --git a/content/public/browser/utility_process_host.h b/content/public/browser/utility_process_host.h
index 2f49727863b020999caae814cf6947b7a60d8684..d131f5b5267234313f5ecc4017c84e77f4b541cb 100644
--- a/content/public/browser/utility_process_host.h
+++ b/content/public/browser/utility_process_host.h
@@ -17,7 +17,7 @@ class FilePath;
class SequencedTaskRunner;
}
-namespace shell {
+namespace service_manager {
class InterfaceProvider;
}
@@ -34,7 +34,7 @@ struct ChildProcessData;
// EndBatchMode().
// If you need to bind Mojo interfaces, use Start() to start the child
// process and GetRemoteInterfaces() to get the utility process'
-// shell::InterfaceProvider.
+// service_manager::InterfaceProvider.
//
// Note: If your class keeps a ptr to an object of this type, grab a weak ptr to
// avoid a use after free since this object is deleted synchronously but the
@@ -82,9 +82,10 @@ class UtilityProcessHost : public IPC::Sender {
// Starts the utility process.
virtual bool Start() = 0;
// Returns the shell::InterfaceProvider the browser process can use to bind
// interfaces exposed to it from the utility process.
- virtual shell::InterfaceProvider* GetRemoteInterfaces() = 0;
+ virtual service_manager::InterfaceProvider* GetRemoteInterfaces() = 0;
// Set the name of the process to appear in the task manager.
virtual void SetName(const base::string16& name) = 0;
« no previous file with comments | « content/public/browser/render_process_host.h ('k') | content/public/browser/web_contents.h » ('j') | no next file with comments »
@@ -82,9 +82,10 @@ class UtilityProcessHost : public IPC::Sender {
// Starts the utility process.
virtual bool Start() = 0;
- // Returns the shell::InterfaceProvider the browser process can use to bind
+ // Returns the service_manager::InterfaceProvider the browser process can use
+ // to bind
// interfaces exposed to it from the utility process.

Powered by Google App Engine
This is Rietveld 408576698